package io.sixminutes.breakingnews

import android.os.Build
import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.result.contract.ActivityResultContracts
import androidx.compose.foundation.layout.*
import androidx.compose.material3.Button
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.runtime.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import io.sixminutes.breakingnews.ui.theme.BreakingnewsTheme

class MainActivity : ComponentActivity() {
    private val TAG = "BreakingNews"

    // 定义 ActivityResultLauncher
    private val interstitialLauncher = registerForActivityResult(
        ActivityResultContracts.StartActivityForResult()
    ) { result ->
        if (result.resultCode == RESULT_OK) {
            val status = result.data?.getStringExtra("AD_STATUS") ?: "Unknown"
            // 更新广告状态
            updateAdStatus(status)
        }
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        setContent {
            BreakingnewsTheme {
                Scaffold(modifier = Modifier.fillMaxSize()) { innerPadding ->
                    Box(
                        modifier = Modifier
                            .fillMaxSize()
                            .padding(innerPadding),
                        contentAlignment = Alignment.Center
                    ) {
                        MainContent()
                    }
                }
            }
        }
    }

    @Composable
    fun MainContent() {
        val deviceModel = Build.MODEL
        var adStatus by remember { mutableStateOf("Ad Status: Unknown") }

        Column(
            modifier = Modifier.fillMaxSize(),
            verticalArrangement = Arrangement.Center,
            horizontalAlignment = Alignment.CenterHorizontally
        ) {
            Text(text = "Device Model: $deviceModel")
            Spacer(modifier = Modifier.height(16.dp))

            Button(onClick = {
                // 调用 InterstitialAdManager 显示广告
                InterstitialAdManager.showAd(this@MainActivity, "be20b7a9d66e8895", interstitialLauncher)
                adStatus = "Ad 1 Loading..."
            }) {
                Text(text = "Show Inter Ad 1: be20b7a9d66e8895")
            }

            Spacer(modifier = Modifier.height(16.dp))

            Button(onClick = {
                // 调用 InterstitialAdManager 显示广告
                InterstitialAdManager.showAd(this@MainActivity, "be20b7a9d66e8895", interstitialLauncher)
                adStatus = "Ad 2 Loading..."
            }) {
                Text(text = "Show Inter Ad 2: be20b7a9d66e8896")
            }

            Spacer(modifier = Modifier.height(16.dp))

            Button(onClick = {
                finish()
            }) {
                Text(text = "Kill")
            }

            Spacer(modifier = Modifier.height(16.dp))

            Text(text = adStatus)
        }
    }

    private fun updateAdStatus(status: String) {
        // 更新 UI 中的广告状态
        runOnUiThread {
            setContent {
                BreakingnewsTheme {
                    Scaffold(modifier = Modifier.fillMaxSize()) { innerPadding ->
                        Box(
                            modifier = Modifier
                                .fillMaxSize()
                                .padding(innerPadding),
                            contentAlignment = Alignment.Center
                        ) {
                            MainContent()
                        }
                    }
                }
            }
        }
    }
}